@@ -85,6 +85,12 @@ class BaseClient(metaclass=ABCMeta):
         This path is expected to contain the actual files.
         """
 
+    @abstractmethod
+    def move_torrent(infohash, destination_path):
+        """
+        Move torrent to destination_path.
+        """
+
     @abstractmethod
     def get_files(infohash):
         """
